@@ -25,8 +25,8 @@ def waitSend(chat_id, media_group_size):
 def properSize(fn):
     size = os.stat(fn).st_size
     if fn.endswith('mp4'):
-        return 0 < size and size < (1 << 25)
-    return 0 < size and size < (1 << 23)
+        return 100 < size and size < (1 << 25)
+    return 100 < size and size < (1 << 23)
 
 def getCap(result, limit):
     if result.cap_html_v2:
@@ -44,17 +44,13 @@ def getCap(result, limit):
         suffix = ''
     return cutCaption(result.cap, suffix, limit)
 
-def sendVideo(chat, result, use_url = False):
-    if use_url:
-        video_source = result.video
+def sendVideo(chat, result):
+    if 'doubanio.com' in result.video:
+        cached_url.get(result.video, mode='b', headers={'referer': 'https://www.douban.com/'}, force_cache = True)
+        content = open(cached_url.getFilePath(result.video), 'rb')
     else:
-        os.system('mkdir tmp > /dev/null 2>&1')
-        with open('tmp/video.mp4', 'wb') as f:
-            f.write(cached_url.get(result.video, force_cache=True, mode='b'))
-        if os.stat('tmp/video.mp4').st_size > 50 * 1024 * 1024:
-            return []
-        video_source = open('tmp/video.mp4', 'rb')
-    group = [InputMediaVideo(video_source, 
+        content = result.video
+    group = [InputMediaVideo(content, 
         caption=getCap(result, 1000), parse_mode=result.getParseMode())]
     return chat.bot.send_media_group(chat.id, group, timeout = 20*60)
 
@@ -90,20 +86,12 @@ def prepareCache(img):
     if '.sinaimg.cn' in img:
         cached_url.get(img, mode='b', headers={'referer': 'https://m.weibo.cn/'}, force_cache = True)
         
-def send_v2_imp(chat, result, rotate=0, send_all=False, no_cut=False, size_factor = None, rotate_detail = {}, start_page = 0, use_url = False):
+def send_v2_imp(chat, result, rotate=0, send_all=False, no_cut=False, size_factor = None, rotate_detail = {}, start_page = 0):
     # may need to revisit this line
     if (not result.video) and len(result.imgs) == 1 and result.imgs[0].endswith('mp4'):
         result.video = result.imgs[0]
     if result.video:
-        try:
-            send_result = sendVideo(chat, result, use_url = use_url)
-            if send_result:
-                return send_result
-            raise Exception('video send failed')
-        except Exception as e:
-            if use_url:
-                raise Exception('try download video next time')
-            raise e
+        return sendVideo(chat, result)
 
     img_limit = start_page * 10 + (100 if send_all else 10)
     [prepareCache(img) for img in result.imgs]
@@ -132,12 +120,12 @@ def send_v2_imp(chat, result, rotate=0, send_all=False, no_cut=False, size_facto
         waitSend(chat.id, 1)
         return [chat.send_message(getCap(result, 4000), 
             parse_mode=result.getParseMode(), timeout = 20*60, 
-            disable_web_page_preview = (not isUrl(result.cap)))]
+            disable_web_page_preview = (not isUrl(result.cap) and not isUrl(result.cap_html_v2)))]
 
 def send_v2(chat, result, rotate=0, send_all=False, no_cut=False, size_factor = None, rotate_detail = {}, start_page=0):
     args = {'rotate': rotate, 'send_all': send_all, 'no_cut': no_cut, 
       'size_factor': size_factor, 'rotate_detail': rotate_detail, 
-      'start_page': start_page, 'use_url': True}
+      'start_page': start_page}
     encoutered_errors = set()
     while True:
         try:
@@ -154,12 +142,9 @@ def send_v2(chat, result, rotate=0, send_all=False, no_cut=False, size_factor =
                 wait = int(str(e).split()[-2])
                 time.sleep(wait + 5)
                 continue
-            if "Can't parse entities" in str(e):
+            if "an't parse entities" in str(e):
                 result.no_parse = True
                 continue
-            if 'try download video next time' in str(e):
-                args['use_url'] = False
-                continue
             raise e
 
 def send(chat, url, result, rotate=0, send_all=False):
